@@ -10,6 +10,7 @@
 #include "akregator_part.h"
 #include "akregatorconfig.h"
 #include "articlelistview.h"
+#include "config-akregator.h"
 #include "feed.h"
 #include "fetchqueue.h"
 #include "folder.h"
@@ -39,6 +40,9 @@
 #include <kxmlguifactory.h>
 
 #include <KColorSchemeManager>
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+#include <PimCommon/VerifyNewVersionWidget>
+#endif
 #include <QWidget>
 
 using namespace Akregator;
@@ -108,6 +112,9 @@ public:
     PimCommon::ShareServiceUrlManager *shareServiceManager = nullptr;
     WebEngineViewer::ZoomActionMenu *zoomActionMenu = nullptr;
     QAction *mQuickSearchAction = nullptr;
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+    PimCommon::VerifyNewVersionWidget *mVerifyNewVersionWidget = nullptr;
+#endif
 };
 
 void ActionManagerImpl::slotSettingsChanged()
@@ -155,6 +162,10 @@ ActionManagerImpl::ActionManagerImpl(Part *part, QObject *parent)
     d->tagMenu = nullptr;
     d->actionCollection = part->actionCollection();
     d->shareServiceManager = new PimCommon::ShareServiceUrlManager(this);
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+    d->mVerifyNewVersionWidget = new PimCommon::VerifyNewVersionWidget(this);
+#endif
+
     initPart();
 }
 
@@ -443,6 +454,17 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
     auto manager = KColorSchemeManager::instance();
     coll->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
 
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+#if AKREGATOR_STABLE_VERSION
+    const QString url = QStringLiteral("https://cdn.kde.org/ci-builds/pim/akregator/25.04/windows/");
+#else
+    const QString url = QStringLiteral("https://cdn.kde.org/ci-builds/pim/akregator/master/windows/");
+#endif
+    d->mVerifyNewVersionWidget->addOsUrlInfo(PimCommon::VerifyNewVersionWidget::OsVersion::Windows, url);
+    auto verifyNewVersionAction = d->mVerifyNewVersionWidget->verifyNewVersionAction();
+    coll->addAction(QStringLiteral("verify_check_version"), verifyNewVersionAction);
+#endif
+
     setArticleActionsEnabled(false);
 }
 
@@ -641,14 +663,13 @@ void ActionManagerImpl::initTabWidget(TabWidget *tabWidget)
     action->setText(i18n("Copy &Link Address"));
     connect(action, &QAction::triggered, d->tabWidget, &TabWidget::slotCopyLinkAddress);
 
-    action = new QAction(i18nc("@action", "Copy Image Location"), this);
+    action = new QAction(i18nc("@action", "Copy Image URL"), this);
     action->setIcon(QIcon::fromTheme(QStringLiteral("view-media-visualization")));
     coll->addAction(QStringLiteral("copy_image_location"), action);
     coll->setShortcutsConfigurable(action, false);
     connect(action, &QAction::triggered, d->tabWidget, &TabWidget::slotCopyImageLocation);
 
-    // save Image On Disk
-    action = new QAction(i18nc("@action", "Save Image On Disk…"), this);
+    action = new QAction(i18nc("@action", "Save Image…"), this);
     coll->addAction(QStringLiteral("saveas_imageurl"), action);
     coll->setShortcutsConfigurable(action, false);
     connect(action, &QAction::triggered, d->tabWidget, &TabWidget::slotSaveImageOnDisk);
